@@ -22,7 +22,7 @@
 #ifndef BAR_H
 #define BAR_H
 
-typedef enum {
+enum PaneType {
 	PANE_UNDEF = 0,
 	PANE_COMMENT,
 	PANE_EXIF,
@@ -30,11 +30,9 @@ typedef enum {
 	PANE_KEYWORDS,
 	PANE_GPS,
 	PANE_RATING
-} PaneType;
+};
 
-typedef struct _PaneData PaneData;
-
-struct _PaneData {
+struct PaneData {
 	void (*pane_set_fd)(GtkWidget *pane, FileData *fd); /**< filled in by pane */
 	void (*pane_notify_selection)(GtkWidget *pane, gint count); /**< filled in by pane */
 	gint (*pane_event)(GtkWidget *pane, GdkEvent *event); /**< filled in by pane */
@@ -53,7 +51,7 @@ struct _PaneData {
 
 GtkWidget *bar_new(LayoutWindow *lw);
 GtkWidget *bar_new_from_config(LayoutWindow *lw, const gchar **attribute_names, const gchar **attribute_values);
-GtkWidget *bar_update_from_config(GtkWidget *bar, const gchar **attribute_names, const gchar **attribute_values, LayoutWindow *lw);
+GtkWidget *bar_update_from_config(GtkWidget *bar, const gchar **attribute_names, const gchar **attribute_values, LayoutWindow *lw, gboolean startup);
 
 void bar_close(GtkWidget *bar);
 
@@ -70,8 +68,6 @@ void bar_set_fd(GtkWidget *bar, FileData *fd);
 void bar_notify_selection(GtkWidget *bar, gint count);
 gboolean bar_event(GtkWidget *bar, GdkEvent *event);
 
-gint bar_get_width(GtkWidget *bar);
-
 GtkWidget *bar_pane_expander_title(const gchar *title);
 void bar_update_expander(GtkWidget *pane);
 gboolean bar_pane_translate_title(PaneType type, const gchar *id, gchar **title);
