@@ -22,12 +22,12 @@
 #ifndef COLLECT_IO_H
 #define COLLECT_IO_H
 
-typedef enum {
+enum CollectionLoadFlags {
 	COLLECTION_LOAD_NONE	= 0,
 	COLLECTION_LOAD_APPEND	= 1 << 0,
 	COLLECTION_LOAD_FLUSH	= 1 << 1,
 	COLLECTION_LOAD_GEOMETRY= 1 << 2,
-} CollectionLoadFlags;
+};
 
 gboolean collection_load(CollectionData *cd, const gchar *path, CollectionLoadFlags flags);
 
@@ -67,7 +67,7 @@ void collect_manager_remove(FileData *fd, const gchar *collection);
  * @headerfile collect_manager_flush
  * commit pending operations to disk
  */
-void collect_manager_flush(void);
+void collect_manager_flush();
 
 void collect_manager_notify_cb(FileData *fd, NotifyType type, gpointer data);
 void collect_manager_list(GList **names_exc, GList **names_inc, GList **paths);
