@@ -22,25 +22,25 @@
 #ifndef COLOR_MAN_H
 #define COLOR_MAN_H
 
-typedef enum {
+enum ColorManProfileType {
 	COLOR_PROFILE_NONE = -1,
 	COLOR_PROFILE_MEM = -2,
 	COLOR_PROFILE_SRGB = 0,
 	COLOR_PROFILE_ADOBERGB,
 	COLOR_PROFILE_FILE,
-} ColorManProfileType;
+};
 
-typedef enum {
+enum ColorManReturnType {
 	COLOR_RETURN_SUCCESS = 0,
 	COLOR_RETURN_ERROR,
 	COLOR_RETURN_IMAGE_CHANGED
-} ColorManReturnType;
+};
 
-typedef struct _ColorMan ColorMan;
-typedef void (* ColorManDoneFunc)(ColorMan *cm, ColorManReturnType success, gpointer data);
+struct ColorMan;
+using ColorManDoneFunc = void (*)(ColorMan *, ColorManReturnType, gpointer);
 
 
-struct _ColorMan {
+struct ColorMan {
 	ImageWindow *imd;
 	GdkPixbuf *pixbuf;
 	gint incremental_sync;
@@ -65,13 +65,12 @@ ColorMan *color_man_new_embedded(ImageWindow *imd, GdkPixbuf *pixbuf,
 				 guchar *screen_data, guint screen_data_len);
 void color_man_free(ColorMan *cm);
 
-void color_man_update(void);
+void color_man_update();
 
 void color_man_correct_region(ColorMan *cm, GdkPixbuf *pixbuf, gint x, gint y, gint w, gint h);
 
-void color_man_start_bg(ColorMan *cm, ColorManDoneFunc don_func, gpointer done_data);
-
 gboolean color_man_get_status(ColorMan *cm, gchar **image_profile, gchar **screen_profile);
 
+guchar *heif_color_profile(FileData *fd, guint *profile_len);
 #endif
 /* vim: set shiftwidth=8 softtabstop=0 cindent cinoptions={1s: */
