@@ -24,10 +24,10 @@
 
 #include "similar.h"
 
-/** @typedef DupeMatchType
+/** @enum DupeMatchType
  *  match methods
  */
-typedef enum
+enum DupeMatchType
 {
 	DUPE_MATCH_NONE = 0,
 	DUPE_MATCH_NAME = 1 << 0,
@@ -43,18 +43,17 @@ typedef enum
 	DUPE_MATCH_NAME_CI = 1 << 10,	/**< same as name, but case insensitive */
 	DUPE_MATCH_NAME_CONTENT = 1 << 11,	/**< same name, but different content */
 	DUPE_MATCH_NAME_CI_CONTENT = 1 << 12,	/**< same name - case insensitive, but different content */
-	DUPE_MATCH_ALL = 1 << 13 /**< N.B. this is used as a clamp value in rcfile.c */
-} DupeMatchType;
+	DUPE_MATCH_ALL = 1 << 13 /**< N.B. this is used as a clamp value in rcfile.cc */
+};
 
-typedef enum
+enum DupeSelectType
 {
 	DUPE_SELECT_NONE,
 	DUPE_SELECT_GROUP1,
 	DUPE_SELECT_GROUP2
-} DupeSelectType;
+};
 
-typedef struct _DupeItem DupeItem;
-struct _DupeItem
+struct DupeItem
 {
 	CollectionData *collection;	/**< NULL if from #DupeWindow->files */
 	CollectInfo *info;
@@ -76,15 +75,13 @@ struct _DupeItem
 	gint second;
 };
 
-typedef struct _DupeMatch DupeMatch;
-struct _DupeMatch
+struct DupeMatch
 {
 	DupeItem *di;
 	gdouble rank;
 };
 
-typedef struct _DupeWindow DupeWindow;
-struct _DupeWindow
+struct DupeWindow
 {
 	GList *list;	/**< one entry for each dropped file in 1st set window (#DupeItem) */
 	GList *dupes;			/**< list of dupes (#DupeItem, grouping the #DupeMatch-es) */
@@ -151,7 +148,7 @@ struct _DupeWindow
 };
 
 
-DupeWindow *dupe_window_new(void);
+DupeWindow *dupe_window_new();
 
 void dupe_window_clear(DupeWindow *dw);
 void dupe_window_close(DupeWindow *dw);
