@@ -23,7 +23,7 @@
 #define EDITORS_H
 
 
-typedef enum {
+enum EditorFlags {
 	EDITOR_KEEP_FS            = 0x00000001,
 	EDITOR_VERBOSE            = 0x00000002,
 	EDITOR_VERBOSE_MULTI      = 0x00000004,
@@ -43,9 +43,9 @@ typedef enum {
 	EDITOR_ERROR_SKIPPED      = 0x00800000,
 	/**< mask to match errors only */
 	EDITOR_ERROR_MASK         = ~0xffff,
-} EditorFlags;
+};
 
-struct _EditorDescription {
+struct EditorDescription {
 	gchar *key; 		/**< desktop file name, not including path, including extension */
 	gchar *name; 		/**< Name, localized name presented to user */
 	gchar *icon;		/**< Icon */
@@ -91,12 +91,12 @@ extern GtkListStore *desktop_file_list;
 
 extern GHashTable *editors;
 
-void editor_table_finish(void);
-void editor_table_clear(void);
-GList *editor_get_desktop_files(void);
+void editor_table_finish();
+void editor_table_clear();
+GList *editor_get_desktop_files();
 gboolean editor_read_desktop_file(const gchar *path);
 
-GList *editor_list_get(void);
+GList *editor_list_get();
 
 
 /**
@@ -110,7 +110,7 @@ GList *editor_list_get(void);
  * @param list - list of processed #FileData structures, typically single file or whole list passed to start_editor_* @n
  * @param data - generic pointer
 */
-typedef gint (*EditorCallback) (gpointer ed, EditorFlags flags, GList *list, gpointer data);
+using EditorCallback = gint (*)(gpointer, EditorFlags, GList *, gpointer);
 
 
 void editor_resume(gpointer ed);
@@ -128,8 +128,6 @@ gboolean editor_is_filter(const gchar *key);
 gboolean editor_no_param(const gchar *key);
 const gchar *editor_get_error_str(EditorFlags flags);
 
-const gchar *editor_get_name(const gchar *key);
-
 gboolean is_valid_editor_command(const gchar *key);
 gboolean editor_blocks_file(const gchar *key);
 
