@@ -80,7 +80,6 @@ void file_data_disable_grouping_list(GList *fd_list, gboolean disable);
 gint filelist_sort_compare_filedata(FileData *fa, FileData *fb);
 gint filelist_sort_compare_filedata_full(FileData *fa, FileData *fb, SortType method, gboolean ascend);
 GList *filelist_sort(GList *list, SortType method, gboolean ascend);
-GList *filelist_insert_sort(GList *list, FileData *fd, SortType method, gboolean ascend);
 GList *filelist_sort_full(GList *list, SortType method, gboolean ascend, GCompareFunc cb);
 GList *filelist_insert_sort_full(GList *list, gpointer data, SortType method, gboolean ascend, GCompareFunc cb);
 
@@ -97,8 +96,8 @@ GList *filelist_sort_path(GList *list);
 GList *filelist_recursive(FileData *dir_fd);
 GList *filelist_recursive_full(FileData *dir_fd, SortType method, gboolean ascend);
 
-typedef gboolean (* FileDataGetMarkFunc)(FileData *fd, gint n, gpointer data);
-typedef gboolean (* FileDataSetMarkFunc)(FileData *fd, gint n, gboolean value, gpointer data);
+using FileDataGetMarkFunc = gboolean (*)(FileData *, gint, gpointer);
+using FileDataSetMarkFunc = gboolean (*)(FileData *, gint, gboolean, gpointer);
 gboolean file_data_register_mark_func(gint n, FileDataGetMarkFunc get_mark_func, FileDataSetMarkFunc set_mark_func, gpointer data, GDestroyNotify notify);
 void file_data_get_registered_mark_func(gint n, FileDataGetMarkFunc *get_mark_func, FileDataSetMarkFunc *set_mark_func, gpointer *data);
 
@@ -114,9 +113,6 @@ GList *file_data_filter_file_filter_list(GList *list, GRegex *filter);
 
 GList *file_data_filter_class_list(GList *list, guint filter);
 
-gint file_data_get_user_orientation(FileData *fd);
-void file_data_set_user_orientation(FileData *fd, gint value);
-
 gchar *file_data_sc_list_to_string(FileData *fd);
 
 gchar *file_data_get_sidecar_path(FileData *fd, gboolean existing_only);
@@ -168,7 +164,7 @@ void file_data_sc_free_ci_list(GList *fd_list);
 GList *file_data_process_groups_in_selection(GList *list, gboolean ungroup, GList **ungrouped);
 
 
-typedef void (*FileDataNotifyFunc)(FileData *fd, NotifyType type, gpointer data);
+using FileDataNotifyFunc = void (*)(FileData *, NotifyType, gpointer);
 gboolean file_data_register_notify_func(FileDataNotifyFunc func, gpointer data, NotifyPriority priority);
 gboolean file_data_unregister_notify_func(FileDataNotifyFunc func, gpointer data);
 void file_data_send_notification(FileData *fd, NotifyType type);
@@ -188,5 +184,7 @@ void file_data_inc_page_num(FileData *fd);
 void file_data_dec_page_num(FileData *fd);
 void file_data_set_page_total(FileData *fd, gint page_total);
 void file_data_set_page_num(FileData *fd, gint page_num);
+
+void file_data_dump();
 #endif
 /* vim: set shiftwidth=8 softtabstop=0 cindent cinoptions={1s: */
