@@ -38,8 +38,7 @@ void fullscreen_stop(FullScreenData *fs);
  * 102  screen 0, monitor 1 \n
  * 201  screen 1, monitor 0 \n
  */
-typedef struct _ScreenData ScreenData;
-struct _ScreenData {
+struct ScreenData {
 	gint number;
 	gchar *description;
 	gint x;
@@ -49,7 +48,7 @@ struct _ScreenData {
 };
 
 
-GList *fullscreen_prefs_list(void);
+GList *fullscreen_prefs_list();
 void fullscreen_prefs_list_free(GList *list);
 
 ScreenData *fullscreen_prefs_list_find(GList *list, gint screen);
@@ -57,8 +56,6 @@ ScreenData *fullscreen_prefs_list_find(GList *list, gint screen);
 void fullscreen_prefs_get_geometry(gint screen, GtkWidget *widget, gint *x, gint *y, gint *width, gint *height,
 				   GdkScreen **dest_screen, gboolean *same_region);
 
-gint fullscreen_prefs_find_screen_for_widget(GtkWidget *widget);
-
 GtkWidget *fullscreen_prefs_selection_new(const gchar *text, gint *screen_value, gboolean *above_value);
 
 
