@@ -22,7 +22,7 @@
 #ifndef IMAGE_OVERLAY_H
 #define IMAGE_OVERLAY_H
 
-typedef enum {
+enum ImageOSDFlag {
 	IMAGE_OSD_NONE = 0,
 	IMAGE_OSD_ROTATE_USER,
 	IMAGE_OSD_ROTATE_AUTO,
@@ -31,14 +31,14 @@ typedef enum {
 	IMAGE_OSD_LAST,
 	IMAGE_OSD_ICON,
 	IMAGE_OSD_COUNT
-} ImageOSDFlag;
+};
 
-typedef enum {
+enum OsdShowFlags {
 	OSD_SHOW_NOTHING	= 0,
 	OSD_SHOW_INFO		= 1 << 0,
 	OSD_SHOW_STATUS		= 1 << 1,
 	OSD_SHOW_HISTOGRAM	= 1 << 2
-} OsdShowFlags;
+};
 
 void set_image_overlay_template_string(gchar **template_string, const gchar *value);
 void set_default_image_overlay_template_string(gchar **template_string);
