@@ -21,16 +21,16 @@
 #ifndef LOGWINDOW_H
 #define LOGWINDOW_H
 
-typedef enum
+enum LogType
 {
 	LOG_NORMAL = 0,
 	LOG_MSG,
 	LOG_WARN,
 	LOG_ERROR,
 	LOG_COUNT
-} LogType;
+};
 
-void log_window_new(void);
+void log_window_new(LayoutWindow *lw);
 
 void log_window_append(const gchar *str, LogType type);
 
