@@ -24,14 +24,11 @@
 
 #include <config.h>
 
-#ifdef HAVE_STRVERSCMP
-#  ifndef _GNU_SOURCE
-#    define _GNU_SOURCE
-#  endif
-#endif
-
 #include "intl.h"
 
+#ifdef HAVE_DEVELOPER
+#include "backward.h"
+#endif
 
 /*
  *-------------------------------------
@@ -83,6 +80,8 @@
 #define GQ_TRASH_DIR		"trash"
 #define GQ_WINDOW_LAYOUTS_DIR	"layouts"
 #define GQ_ARCHIVE_DIR	"geeqie-archive"
+#define GQ_RESOURCE_PATH_ICONS "/org/geeqie/icons"
+#define GQ_RESOURCE_PATH_CREDITS "/org/geeqie/credits"
 
 #define GQ_SYSTEM_WIDE_DIR    "/etc/" GQ_APPNAME_LC
 
@@ -124,6 +123,7 @@
 #include "debug.h"
 #include "options.h"
 
+#define APPIMAGE_VERSION_FILE "https://raw.githubusercontent.com/geeqie/geeqie.github.io/master/AppImage/appimages.txt"
 #define TIMEZONE_DATABASE_WEB "https://cdn.bertold.org/zonedetect/db/db.zip"
 #define TIMEZONE_DATABASE_FILE "timezone21.bin"
 #define TIMEZONE_DATABASE_VERSION "out_v1"
@@ -145,12 +145,12 @@
 
 /*
  *----------------------------------------------------------------------------
- * main.c
+ * main.cc
  *----------------------------------------------------------------------------
  */
 
 /*
- * This also doubles as the main.c header.
+ * This also doubles as the main.cc header.
  */
 
 extern gboolean thumb_format_changed;
@@ -168,7 +168,7 @@ extern gchar *instance_identifier;
 void keyboard_scroll_calc(gint *x, gint *y, GdkEventKey *event);
 gint key_press_cb(GtkWidget *widget, GdkEventKey *event, gpointer data);
 
-void exit_program(void);
+void exit_program();
 
 #define CASE_SORT(a, b) ( (options->file_sort.case_sensitive) ? strcmp((a), (b)) : strcasecmp((a), (b)) )
 
