@@ -21,9 +21,7 @@
 #ifndef OPTIONS_H
 #define OPTIONS_H
 
-typedef struct _ConfOptions ConfOptions;
-
-struct _ConfOptions
+struct ConfOptions
 {
 	/* ui */
 	gboolean progressive_key_scrolling;
@@ -75,6 +73,8 @@ struct _ConfOptions
 	gboolean marks_save;		/**< save marks on exit */
 	gchar *marks_tooltips[FILEDATA_MARKS_SIZE];
 
+	gboolean appimage_notifications;
+
 	gboolean with_rename;
 	gboolean collections_on_top;
 	gboolean hide_window_in_fullscreen;
@@ -346,6 +346,7 @@ struct _ConfOptions
 		gboolean paused;
 		gboolean line_wrap;
 		gboolean timer_data;
+		gchar *action; /** Used with F1 key */
 	} log_window;
 
 	/* star rating */
@@ -378,8 +379,8 @@ struct _ConfOptions
 
 	gboolean read_metadata_in_idle;
 
-	gboolean disable_gpu; /**< GPU - see main.c */
-	gboolean override_disable_gpu; /**< GPU - see main.c */
+	gboolean disable_gpu; /**< GPU - see main.cc */
+	gboolean override_disable_gpu; /**< GPU - see main.cc */
 
 	GList *disabled_plugins;
 };
