@@ -22,24 +22,31 @@
 #ifndef TYPEDEFS_H
 #define TYPEDEFS_H
 
-typedef enum {
+enum ZoomMode {
 	ZOOM_RESET_ORIGINAL	= 0,
 	ZOOM_RESET_FIT_WINDOW	= 1,
 	ZOOM_RESET_NONE		= 2
-} ZoomMode;
+};
 
-typedef enum {
+enum ZoomStyle {
 	ZOOM_GEOMETRIC	= 0,
 	ZOOM_ARITHMETIC	= 1
-} ZoomStyle;
+};
 
-typedef enum {
+enum ClipboardDestination {
+	CLIPBOARD_TEXT_PLAIN	= 0,
+	CLIPBOARD_TEXT_URI_LIST	= 1,
+	CLIPBOARD_X_SPECIAL_GNOME_COPIED_FILES	= 2,
+	CLIPBOARD_UTF8_STRING	= 3
+};
+
+enum ClipboardSelection {
 	CLIPBOARD_PRIMARY	= 0,
 	CLIPBOARD_CLIPBOARD = 1,
 	CLIPBOARD_BOTH = 2
-} ClipboardSelection;
+};
 
-typedef enum {
+enum MouseButton {
 	MOUSE_BUTTON_LEFT	= 1,
 	MOUSE_BUTTON_MIDDLE	= 2,
 	MOUSE_BUTTON_RIGHT	= 3,
@@ -47,21 +54,21 @@ typedef enum {
 	MOUSE_BUTTON_WHEEL_DOWN	= 5,
 	MOUSE_BUTTON_8	= 8,
 	MOUSE_BUTTON_9	= 9
-} MouseButton;
+};
 
-typedef enum {
+enum DirViewType {
 	DIRVIEW_LIST,
 	DIRVIEW_TREE,
 
 	DIRVIEW_LAST = DIRVIEW_TREE /**< Keep this up to date! */
-} DirViewType;
+};
 
-typedef enum {
+enum FileViewType {
 	FILEVIEW_LIST,
 	FILEVIEW_ICON,
 
 	FILEVIEW_LAST = FILEVIEW_ICON /**< Keep this up to date! */
-} FileViewType;
+};
 
 #define	CMD_COPY     "geeqie-copy-command.desktop"
 #define	CMD_MOVE     "geeqie-move-command.desktop"
@@ -69,49 +76,48 @@ typedef enum {
 #define	CMD_DELETE   "geeqie-delete-command.desktop"
 #define	CMD_FOLDER   "geeqie-folder-command.desktop"
 
-typedef enum {
+enum SortType {
 	SORT_NONE,
 	SORT_NAME,
 	SORT_SIZE,
 	SORT_TIME,
 	SORT_CTIME,
 	SORT_PATH,
-	SORT_NUMBER,
 	SORT_EXIFTIME,
 	SORT_EXIFTIMEDIGITIZED,
 	SORT_RATING,
 	SORT_CLASS
-} SortType;
+};
 
 /**
- * @typedef DnDAction
+ * @enum DnDAction
  * drag and drop default action
  */
-typedef enum {
+enum DnDAction {
 	DND_ACTION_ASK,
 	DND_ACTION_COPY,
 	DND_ACTION_MOVE
-} DnDAction;
+};
 
-typedef enum {
+enum AlterType {
 	ALTER_NONE,		/**< do nothing */
 	ALTER_ROTATE_90,
 	ALTER_ROTATE_90_CC,	/**< counterclockwise */
 	ALTER_ROTATE_180,
 	ALTER_MIRROR,
 	ALTER_FLIP,
-} AlterType;
+};
 
-typedef enum {
+enum LayoutLocation {
 	LAYOUT_HIDE   = 0,
 	LAYOUT_LEFT   = 1 << 0,
 	LAYOUT_RIGHT  = 1 << 1,
 	LAYOUT_TOP    = 1 << 2,
 	LAYOUT_BOTTOM = 1 << 3
-} LayoutLocation;
+};
 
 
-typedef enum {
+enum ImageState {
 	IMAGE_STATE_NONE	= 0,
 	IMAGE_STATE_IMAGE	= 1 << 0,
 	IMAGE_STATE_LOADING	= 1 << 1,
@@ -120,38 +126,39 @@ typedef enum {
 	IMAGE_STATE_ROTATE_AUTO	= 1 << 4,
 	IMAGE_STATE_ROTATE_USER	= 1 << 5,
 	IMAGE_STATE_DELAY_FLIP	= 1 << 6
-} ImageState;
+};
 
-typedef enum {
+enum ImageSplitMode {
 	SPLIT_NONE = 0,
 	SPLIT_VERT,
 	SPLIT_HOR,
+	SPLIT_TRIPLE,
 	SPLIT_QUAD,
-} ImageSplitMode;
+};
 
-typedef enum {
+enum FileDataChangeType {
 	FILEDATA_CHANGE_DELETE,
 	FILEDATA_CHANGE_MOVE,
 	FILEDATA_CHANGE_RENAME,
 	FILEDATA_CHANGE_COPY,
 	FILEDATA_CHANGE_UNSPECIFIED,
 	FILEDATA_CHANGE_WRITE_METADATA
-} FileDataChangeType;
+};
 
-typedef enum {
+enum MarkToSelectionMode {
 	MTS_MODE_MINUS,
 	MTS_MODE_SET,
 	MTS_MODE_OR,
 	MTS_MODE_AND
-} MarkToSelectionMode;
+};
 
-typedef enum {
+enum SelectionToMarkMode {
 	STM_MODE_RESET,
 	STM_MODE_SET,
 	STM_MODE_TOGGLE
-} SelectionToMarkMode;
+};
 
-typedef enum {
+enum FileFormatClass {
 	FORMAT_CLASS_UNKNOWN,
 	FORMAT_CLASS_IMAGE,
 	FORMAT_CLASS_RAWIMAGE,
@@ -161,15 +168,15 @@ typedef enum {
 	FORMAT_CLASS_DOCUMENT,
 	FORMAT_CLASS_ARCHIVE,
 	FILE_FORMAT_CLASSES
-} FileFormatClass;
+};
 
-extern gchar *format_class_list[]; /**< defined in preferences.c */
+extern const gchar *format_class_list[]; /**< defined in preferences.cc */
 
 /**
- * @typedef SecureSaveErrno
+ * @enum SecureSaveErrno
  * see err field in #SecureSaveInfo
  */
-typedef enum {
+enum SecureSaveErrno {
 	SS_ERR_NONE = 0,
 	SS_ERR_DISABLED, /**< secsave is disabled. */
 	SS_ERR_OUT_OF_MEM, /**< memory allocation failure */
@@ -181,15 +188,15 @@ typedef enum {
 	SS_ERR_MKSTEMP,
 	SS_ERR_RENAME,
 	SS_ERR_OTHER,
-} SecureSaveErrno;
+};
 
-typedef enum {
+enum NotifyPriority {
 	NOTIFY_PRIORITY_HIGH = 0,
 	NOTIFY_PRIORITY_MEDIUM,
 	NOTIFY_PRIORITY_LOW
-} NotifyPriority;
+};
 
-typedef enum {
+enum NotifyType {
 	NOTIFY_MARKS		= 1 << 1, /**< changed marks */
 	NOTIFY_PIXBUF		= 1 << 2, /**< image was read into fd->pixbuf */
 	NOTIFY_HISTMAP		= 1 << 3, /**< histmap was read into fd->histmap */
@@ -198,9 +205,9 @@ typedef enum {
 	NOTIFY_GROUPING		= 1 << 6, /**< change in fd->sidecar_files or fd->parent */
 	NOTIFY_REREAD		= 1 << 7, /**< changed file size, date, etc., file name remains unchanged */
 	NOTIFY_CHANGE		= 1 << 8  /**< generic change described by fd->change */
-} NotifyType;
+};
 
-typedef enum {
+enum ChangeError {
 	CHANGE_OK                      = 0,
 	CHANGE_WARN_DEST_EXISTS        = 1 << 0,
 	CHANGE_WARN_NO_WRITE_PERM      = 1 << 1,
@@ -217,26 +224,26 @@ typedef enum {
 	CHANGE_DEST_EXISTS             = 1 << 13,
 	CHANGE_NO_SRC                  = 1 << 14,
 	CHANGE_GENERIC_ERROR           = 1 << 16
-} ChangeError;
+};
 
-typedef enum {
+enum MetadataFormat {
 	METADATA_PLAIN		= 0, /**< format that can be edited and written back */
 	METADATA_FORMATTED	= 1  /**< for display only */
-} MetadataFormat;
+};
 
-typedef enum {
+enum StartUpPath {
 	STARTUP_PATH_CURRENT	= 0,
 	STARTUP_PATH_LAST,
 	STARTUP_PATH_HOME,
-} StartUpPath;
+};
 
-typedef enum {
+enum ToolbarType {
 	TOOLBAR_MAIN,
 	TOOLBAR_STATUS,
 	TOOLBAR_COUNT
-} ToolbarType;
+};
 
-typedef enum {
+enum PixbufRendererStereoMode {
 	PR_STEREO_NONE             = 0,	  /**< do nothing */
 	PR_STEREO_DUAL             = 1 << 0, /**< independent stereo buffers, for example nvidia opengl */
 	PR_STEREO_FIXED            = 1 << 1,  /**< custom position */
@@ -273,85 +280,85 @@ typedef enum {
 	PR_STEREO_SWAP             = 1 << 18,  /**< swap left and right buffers */
 	PR_STEREO_TEMP_DISABLE     = 1 << 19,  /**< temporarily disable stereo mode if source image is not stereo */
 	PR_STEREO_HALF             = 1 << 20
-} PixbufRendererStereoMode;
+};
 
-typedef enum {
+enum StereoPixbufData {
 	STEREO_PIXBUF_DEFAULT  = 0,
 	STEREO_PIXBUF_SBS      = 1,
 	STEREO_PIXBUF_CROSS    = 2,
 	STEREO_PIXBUF_NONE     = 3
-} StereoPixbufData;
+};
 
-typedef enum {
+enum SortModeType {
 	BAR_SORT_MODE_FOLDER = 0,
 	BAR_SORT_MODE_COLLECTION,
 	BAR_SORT_MODE_COUNT
-} SortModeType;
+};
 
-typedef enum {
+enum SortActionType {
 	BAR_SORT_COPY = 0,
 	BAR_SORT_MOVE,
 	BAR_SORT_FILTER,
 	BAR_SORT_ACTION_COUNT
-} SortActionType;
+};
 
-typedef enum {
+enum SortSelectionType {
 	BAR_SORT_SELECTION_IMAGE = 0,
 	BAR_SORT_SELECTION_SELECTED,
 	BAR_SORT_SELECTION_COUNT
-} SortSelectionType;
+};
 
 #define MAX_SPLIT_IMAGES 4
 
-typedef enum {
+enum SelectionType {
 	SELECTION_NONE		= 0,
 	SELECTION_SELECTED	= 1 << 0,
 	SELECTION_PRELIGHT	= 1 << 1,
 	SELECTION_FOCUS		= 1 << 2
-} SelectionType;
+};
 
-typedef struct _ImageLoader ImageLoader;
-typedef struct _ThumbLoader ThumbLoader;
+struct ImageLoader;
+struct ThumbLoader;
 
-typedef struct _AnimationData AnimationData;
+struct AnimationData;
 
-typedef struct _CollectInfo CollectInfo;
-typedef struct _CollectionData CollectionData;
-typedef struct _CollectTable CollectTable;
-typedef struct _CollectWindow CollectWindow;
+struct CollectInfo;
+struct CollectionData;
+struct CollectTable;
+struct CollectWindow;
 
-typedef struct _ImageWindow ImageWindow;
+struct ImageWindow;
 
-typedef struct _FileData FileData;
-typedef struct _FileDataChangeInfo FileDataChangeInfo;
+struct FileData;
+struct FileDataChangeInfo;
 
-typedef struct _LayoutWindow LayoutWindow;
-typedef struct _LayoutOptions LayoutOptions;
+struct LayoutWindow;
+struct LayoutOptions;
 
-typedef struct _ViewDir ViewDir;
-typedef struct _ViewDirInfoList ViewDirInfoList;
-typedef struct _ViewDirInfoTree ViewDirInfoTree;
+struct ViewDir;
+struct ViewDirInfoList;
+struct ViewDirInfoTree;
 
-typedef struct _ViewFile ViewFile;
-typedef struct _ViewFileInfoList ViewFileInfoList;
-typedef struct _ViewFileInfoIcon ViewFileInfoIcon;
+struct ViewFile;
+struct ViewFileInfoList;
+struct ViewFileInfoIcon;
 
-typedef struct _SlideShowData SlideShowData;
-typedef struct _FullScreenData FullScreenData;
+struct SlideShowData;
+struct FullScreenData;
 
-typedef struct _PixmapFolders PixmapFolders;
-typedef struct _Histogram Histogram;
-typedef struct _HistMap HistMap;
+struct PixmapFolders;
+struct Histogram;
+struct HistMap;
 
-typedef struct _SecureSaveInfo SecureSaveInfo;
+struct SecureSaveInfo;
 
-typedef struct _ExifData ExifData;
+struct ExifData;
 
-typedef struct _EditorDescription EditorDescription;
+struct EditorDescription;
 
-typedef struct _CommandLine CommandLine;
+struct CommandLine;
 
-struct _Histogram {
+struct Histogram {
 	gint histogram_channel; /**< drawing mode for histogram */
 	gint histogram_mode;     /**< logarithmical or not */
 	guint vgrid; /**< number of vertical divisions, 0 for none */
@@ -367,13 +374,13 @@ struct _Histogram {
 
 
 
-struct _ImageLoader;
+struct ImageLoader;
 
-typedef void (* ThumbLoaderFunc)(ThumbLoader *tl, gpointer data);
+using ThumbLoaderFunc = void (*)(ThumbLoader *, gpointer);
 
-typedef void (* FileUtilDoneFunc)(gboolean success, const gchar *done_path, gpointer data);
+using FileUtilDoneFunc = void (*)(gboolean, const gchar *, gpointer);
 
-struct _ThumbLoader
+struct ThumbLoader
 {
 	gboolean standard_loader;
 
@@ -396,7 +403,7 @@ struct _ThumbLoader
 	guint idle_done_id; /**< event source id */
 };
 
-struct _AnimationData
+struct AnimationData
 {
 	ImageWindow *iw;
 	LayoutWindow *lw;
@@ -411,14 +418,14 @@ struct _AnimationData
 	GFileInputStream *gfstream;
 };
 
-struct _CollectInfo
+struct CollectInfo
 {
 	FileData *fd;
 	GdkPixbuf *pixbuf;
 	guint flag_mask;
 };
 
-struct _CollectionData
+struct CollectionData
 {
 	gchar *path;
 	gchar *name;
@@ -445,7 +452,7 @@ struct _CollectionData
 	GHashTable *existence;
 };
 
-struct _CollectTable
+struct CollectTable
 {
 	GtkWidget *scrolled;
 	GtkWidget *listview;
@@ -486,7 +493,7 @@ struct _CollectTable
 	GList *editmenu_fd_list; /**< file list for edit menu */
 };
 
-struct _CollectWindow
+struct CollectWindow
 {
 	GtkWidget *window;
 	CollectTable *table;
@@ -497,12 +504,10 @@ struct _CollectWindow
 	CollectionData *cd;
 };
 
-typedef gint (* ImageTileRequestFunc)(ImageWindow *imd, gint x, gint y,
-				      gint width, gint height, GdkPixbuf *pixbuf, gpointer);
-typedef void (* ImageTileDisposeFunc)(ImageWindow *imd, gint x, gint y,
-				      gint width, gint height, GdkPixbuf *pixbuf, gpointer);
+using ImageTileRequestFunc = gint (*)(ImageWindow *, gint, gint, gint, gint, GdkPixbuf *, gpointer);
+using ImageTileDisposeFunc = void (*)(ImageWindow *, gint, gint, gint, gint, GdkPixbuf *, gpointer);
 
-struct _ImageWindow
+struct ImageWindow
 {
 	GtkWidget *widget;	/**< use this to add it and show it */
 	GtkWidget *pr;
@@ -588,7 +593,7 @@ struct _ImageWindow
 
 #define FILEDATA_MARKS_SIZE 10
 
-struct _FileDataChangeInfo {
+struct FileDataChangeInfo {
 	FileDataChangeType type;
 	gchar *source;
 	gchar *dest;
@@ -596,7 +601,7 @@ struct _FileDataChangeInfo {
 	gboolean regroup_when_finished;
 };
 
-struct _FileData {
+struct FileData {
 	guint magick;
 	gint type;
 	gchar *original_path; /**< key to file_data_pool hash table */
@@ -648,13 +653,13 @@ struct _FileData {
 	gchar *group;
 	gchar *sym_link;
 
-	SelectionType selected;  /**< Used by view_file_icon. */
+	SelectionType selected;  /**< Used by view-file-icon. */
 
 	gint page_num;
 	gint page_total;
 };
 
-struct _LayoutOptions
+struct LayoutOptions
 {
 	gchar *id;
 
@@ -772,7 +777,7 @@ struct _LayoutOptions
 	gchar *filter_key;
 };
 
-struct _LayoutWindow
+struct LayoutWindow
 {
 	LayoutOptions options;
 
@@ -895,7 +900,7 @@ struct _LayoutWindow
 	GtkWidget *log_window;
 };
 
-struct _ViewDir
+struct ViewDir
 {
 	DirViewType type;
 	gpointer info;
@@ -925,21 +930,21 @@ struct _ViewDir
 	PixmapFolders *pf;
 };
 
-struct _ViewDirInfoList
+struct ViewDirInfoList
 {
 	GList *list;
 };
 
-struct _ViewDirInfoTree
+struct ViewDirInfoTree
 {
 	guint drop_expand_id; /**< event source id */
 	gint busy_ref;
 };
 
 
-struct _ViewFile
+struct ViewFile
 {
-	FileViewType type; 	/**< @todo (xsdg): Turn this into a union (see VFLIST and VFICON from view_file.h). */
+	FileViewType type; 	/**< @todo (xsdg): Turn this into a union (see VFLIST and VFICON from view-file.h). */
 
 	gpointer info;
 
@@ -997,7 +1002,7 @@ struct _ViewFile
 	guint read_metadata_in_idle_id;
 };
 
-struct _ViewFileInfoList
+struct ViewFileInfoList
 {
 	FileData *click_fd;
 	FileData *select_fd;
@@ -1007,7 +1012,7 @@ struct _ViewFileInfoList
 	guint select_idle_id; /**< event source id */
 };
 
-struct _ViewFileInfoIcon
+struct ViewFileInfoIcon
 {
 	/* table stuff */
 	gint columns;
@@ -1029,11 +1034,11 @@ struct _ViewFileInfoIcon
 	gboolean show_text;
 };
 
-struct _SlideShowData
+struct SlideShowData
 {
 	LayoutWindow *lw;        /**< use this window to display the slideshow */
 	ImageWindow *imd;        /**< use this window only if lw is not available,
-	                            @FIXME it is probably required only by img-view.c and should be dropped with it */
+	                            @FIXME it is probably required only by img-view.cc and should be dropped with it */
 
 	GList *filelist;
 	CollectionData *cd;
@@ -1055,7 +1060,7 @@ struct _SlideShowData
 	gboolean paused;
 };
 
-struct _FullScreenData
+struct FullScreenData
 {
 	GtkWidget *window;
 	ImageWindow *imd;
@@ -1076,16 +1081,17 @@ struct _FullScreenData
 	gboolean same_region; /**< the returned region will overlap the current location of widget. */
 };
 
-struct _PixmapFolders
+struct PixmapFolders
 {
 	GdkPixbuf *close;
 	GdkPixbuf *open;
 	GdkPixbuf *deny;
 	GdkPixbuf *parent;
 	GdkPixbuf *link;
+	GdkPixbuf *read_only;
 };
 
-struct _SecureSaveInfo {
+struct SecureSaveInfo {
 	FILE *fp; /**< file stream pointer */
 	gchar *file_name; /**< final file name */
 	gchar *tmp_file_name; /**< temporary file name */
@@ -1096,7 +1102,7 @@ struct _SecureSaveInfo {
 	gboolean unlink_on_error; /**< whether to remove temporary file on save failure, TRUE by default */
 };
 
-struct _CommandLine
+struct CommandLine
 {
 	int argc;
 	gchar **argv;
@@ -1119,19 +1125,18 @@ struct _CommandLine
 };
 
 /**
- * @struct _hard_coded_window_keys
+ * @struct hard_coded_window_keys
  * @brief hard coded window shortcut keys
- * 
+ *
  * Used for two purposes:\n
  * to display the shortcuts keys in popup menus\n
  * used by ./doc/create-shortcuts-xml.sh to generate shortcut documentation in the Help files
- * 
+ *
  */
-typedef struct _hard_coded_window_keys hard_coded_window_keys;
-struct _hard_coded_window_keys {
+struct hard_coded_window_keys {
 	GdkModifierType mask; /**< modifier key mask */
 	guint key_value;  /**< GDK_keyval */
-	gchar *text;  /**< menu item label - NULL if end of list */
+	const gchar *text;  /**< menu item label - NULL if end of list */
 };
 
 #endif
